# Craftbeerpi4 PushOver Notifications Plugin

## Plugin to forward Craftbeerpi4 Notifications to Pushover Push Notification service

- Installation:

	- Plugin requires cbpi >= 4.0.0.33
	- pip install cbpi4-PushOver
	- or installation from github
	- cbpi add cbpi4-PushOver

- Usage:

	- First Installation will add parameters to settings.
	- Configure settings by adding token and user.
	- Restart cbpi

- Parameters:

	- pushover_token: your token for this service
	- pushover_user: your user for this service

### Changelog:

- 10.05.22: (0.0.5) Updated README (removed cbpi add)
- 10.05.22: (0.0.4) Removed cbpi dependency
- 02.04.21:  Minor changes
- 15.03.21: Initial Release.
